@@ -88,7 +88,6 @@ enum {
 
 static void     gsm_inhibit_dialog_class_init  (GsmInhibitDialogClass *klass);
 static void     gsm_inhibit_dialog_init        (GsmInhibitDialog      *inhibit_dialog);
-static void     gsm_inhibit_dialog_finalize    (GObject               *object);
 
 G_DEFINE_TYPE (GsmInhibitDialog, gsm_inhibit_dialog, GTK_TYPE_DIALOG)
 
@@ -509,11 +508,11 @@ update_dialog_text (GsmInhibitDialog *dialog)
         if (model_has_one_entry (GTK_TREE_MODEL (dialog->priv->list_store))) {
                 g_debug ("Found one entry in model");
                 header_text = _("A program is still running:");
-                description_text = _("Waiting for the program to finish.  Interrupting the program may cause you to lose work.");
+                description_text = _("Waiting for the program to finish. Interrupting the program may cause you to lose work.");
         } else {
                 g_debug ("Found multiple entries (or none) in model");
                 header_text = _("Some programs are still running:");
-                description_text = _("Waiting for programs to finish.  Interrupting these programs may cause you to lose work.");
+                description_text = _("Waiting for programs to finish. Interrupting these programs may cause you to lose work.");
         }
 
         widget = GTK_WIDGET (gtk_builder_get_object (dialog->priv->xml,
@@ -899,7 +898,6 @@ gsm_inhibit_dialog_class_init (GsmInhibitDialogClass *klass)
         object_class->set_property = gsm_inhibit_dialog_set_property;
         object_class->constructor = gsm_inhibit_dialog_constructor;
         object_class->dispose = gsm_inhibit_dialog_dispose;
-        object_class->finalize = gsm_inhibit_dialog_finalize;
 
         g_object_class_install_property (object_class,
                                          PROP_ACTION,
@@ -966,23 +964,6 @@ gsm_inhibit_dialog_init (GsmInhibitDialog *dialog)
                       NULL);
 }
 
-static void
-gsm_inhibit_dialog_finalize (GObject *object)
-{
-        GsmInhibitDialog *dialog;
-
-        g_return_if_fail (object != NULL);
-        g_return_if_fail (GSM_IS_INHIBIT_DIALOG (object));
-
-        dialog = GSM_INHIBIT_DIALOG (object);
-
-        g_return_if_fail (dialog->priv != NULL);
-
-        g_debug ("GsmInhibitDialog: finalizing");
-
-        G_OBJECT_CLASS (gsm_inhibit_dialog_parent_class)->finalize (object);
-}
-
 GtkWidget *
 gsm_inhibit_dialog_new (GsmStore *inhibitors,
                         GsmStore *clients,
