@@ -21,7 +21,6 @@
 #define __GSM_UTIL_H__
 
 #include <glib.h>
-#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
@@ -55,8 +54,6 @@ char *      gsm_util_generate_startup_id            (void);
 void        gsm_util_setenv                         (const char *variable,
                                                      const char *value);
 
-GtkIconSize gsm_util_get_computer_fail_icon_size    (void);
-
 G_END_DECLS
 
 #endif /* __GSM_UTIL_H__ */
