@@ -48,6 +48,10 @@
 #include "gsm-system.h"
 #include "gsm-fail-whale.h"
 
+#ifdef HAVE_SYSTEMD
+#include <systemd/sd-journal.h>
+#endif
+
 #define GSM_DBUS_NAME "org.gnome.SessionManager"
 
 static gboolean failsafe = FALSE;
@@ -330,6 +334,22 @@ main (int argc, char **argv)
                 exit (0);
         }
 
+        /* Rebind stdout/stderr to the journal explicitly, so that
+         * journald picks ups the nicer "gnome-session" as the program
+         * name instead of whatever shell script GDM happened to use.
+         */
+#ifdef HAVE_SYSTEMD
+        if (!debug) {
+                int journalfd;
+
+                journalfd = sd_journal_stream_fd (PACKAGE, LOG_INFO, 0);
+                if (journalfd >= 0) {
+                        dup2(journalfd, 1);
+                        dup2(journalfd, 2);
+                }
+        }
+#endif
+
         if (gl_failed) {
                 gsm_fail_whale_dialog_we_failed (FALSE, TRUE, NULL);
                 gtk_main ();
